@@ -30,6 +30,7 @@ class ApiClient:
     RS232_HANDSHAKE_CLIENT_REQUEST = 'OPEN'
     RS232_HANDSHAKE_SERVER_RESPONSE = 'LISA'
 
+    connection = None
     for i in range(1, MAX_COM_TO_TRY):
       try:
         endpoint = "COM{}".format(i)
@@ -44,15 +45,15 @@ class ApiClient:
         response = connection.read(len(RS232_HANDSHAKE_SERVER_RESPONSE))
         if len(response) > 0 and str(response.decode()) == RS232_HANDSHAKE_SERVER_RESPONSE:
           log.debug('Detect Open LISA server at {}'.format(endpoint))
-          self._connection = connection
-          return
+          break
         else:
           log.debug("no answer detected from {}".format(endpoint))
       except serial.SerialException as ex:
         log.info('serial exception {}'.format(ex))
         log.debug("could not connect to {}".format(endpoint))
 
-        raise CouldNotConnectToServerException("could not detect Open LISA server listening through RS232")
+    if not connection:
+      raise CouldNotConnectToServerException("could not detect Open LISA server listening through RS232")
 
     self._client_protocol = ClientProtocol(MessageProtocolRS232(rs232_connection=connection))
 
